Index: src/ia32/builtins-ia32.cc |
diff --git a/src/ia32/builtins-ia32.cc b/src/ia32/builtins-ia32.cc |
index 44f0a977dca4e227046c37cb8596c6fcb4ec71bd..1dffae95468188bf8cd449833e93dd06aa895d1f 100644 |
--- a/src/ia32/builtins-ia32.cc |
+++ b/src/ia32/builtins-ia32.cc |
@@ -359,8 +359,8 @@ static void Generate_JSConstructStubHelper(MacroAssembler* masm, |
__ j(zero, &use_receiver); |
// If the type of the result (stored in its map) is less than |
- // FIRST_JS_OBJECT_TYPE, it is not an object in the ECMA sense. |
- __ CmpObjectType(eax, FIRST_JS_OBJECT_TYPE, ecx); |
+ // FIRST_SPEC_OBJECT_TYPE, it is not an object in the ECMA sense. |
+ __ CmpObjectType(eax, FIRST_SPEC_OBJECT_TYPE, ecx); |
__ j(above_equal, &exit); |
// Throw away the result of the constructor invocation and use the |
@@ -617,8 +617,9 @@ void Builtins::Generate_FunctionCall(MacroAssembler* masm) { |
// We don't use IsObjectJSObjectType here because we jump on success. |
__ mov(ecx, FieldOperand(ebx, HeapObject::kMapOffset)); |
__ movzx_b(ecx, FieldOperand(ecx, Map::kInstanceTypeOffset)); |
- __ sub(Operand(ecx), Immediate(FIRST_JS_OBJECT_TYPE)); |
- __ cmp(ecx, LAST_JS_OBJECT_TYPE - FIRST_JS_OBJECT_TYPE); |
+ __ sub(Operand(ecx), Immediate(FIRST_NONCALLABLE_SPEC_OBJECT_TYPE)); |
+ __ cmp(ecx, LAST_NONCALLABLE_SPEC_OBJECT_TYPE - |
+ FIRST_NONCALLABLE_SPEC_OBJECT_TYPE); |
__ j(below_equal, &shift_arguments); |
__ bind(&convert_to_object); |
@@ -780,8 +781,9 @@ void Builtins::Generate_FunctionApply(MacroAssembler* masm) { |
// We don't use IsObjectJSObjectType here because we jump on success. |
__ mov(ecx, FieldOperand(ebx, HeapObject::kMapOffset)); |
__ movzx_b(ecx, FieldOperand(ecx, Map::kInstanceTypeOffset)); |
- __ sub(Operand(ecx), Immediate(FIRST_JS_OBJECT_TYPE)); |
- __ cmp(ecx, LAST_JS_OBJECT_TYPE - FIRST_JS_OBJECT_TYPE); |
+ __ sub(Operand(ecx), Immediate(FIRST_NONCALLABLE_SPEC_OBJECT_TYPE)); |
+ __ cmp(ecx, LAST_NONCALLABLE_SPEC_OBJECT_TYPE - |
+ FIRST_NONCALLABLE_SPEC_OBJECT_TYPE); |
__ j(below_equal, &push_receiver); |
// Convert the receiver to an object. |